California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 022 - CHANGES EMPLOYMENT CLASSIFICATION RULES FOR APP-BASED TRANSPORTATION AND DELIVERY DRIVERS. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1428618 | NO ON 22, A COALITION OF ECONOMIC AND SOCIAL JUSTICE NONPROFITS DEDICATED TO WORKERS' RIGHTS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1427634 | SILICON VALLEY RISING ACTION, YES ON PROP 15, NO ON PROP 22 (NONPROFIT 501 C4) | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1433233 | NGUYEN'S YES ON 22 COMMITTEE; SENATOR JANET | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1426273 | KILEY'S BALLOT MEASURE COMMITTEE TO REPEAL AB 5 AND RESTORE THE RIGHT TO EARN A LIVING; LET US WORK, ASSEMBLYMAN KEVIN | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1424537 | NO ON PROP 22, SPONSORED BY LABOR ORGANIZATIONS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1432490 | TEAMSTERS JOINT COUNCIL NO. 42 - NO ON PROP. 22 (NONPROFIT 501(C)(5)) | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1422181 | YES ON 22 - SAVE APP-BASED JOBS AND SERVICES: A COALITION OF ON-DEMAND DRIVERS AND PLATFORMS, SMALL BUSINESSES, PUBLIC SAFETY AND COMMUNITY ORGANIZATIONS | SUPPORT